@@ -1,3 +1,4 @@
+import re
 from abc import ABC, abstractmethod
 from time import time
 
@@ -15,20 +16,26 @@ class Script(ABC):
     def name(self) -> str:
         return self.__class__.__name__.lower()
 
+    @property
+    def title(self) -> str:
+        return re.sub(r"([A-Z])", r" \1", self.__class__.__name__).strip()
+
     def loop(self, duration: int = 0, *, max_failed: int = 10, dev: bool = False):
         start = time()
         elapsed = 0.0
         while (elapsed < duration or not duration) and self.failed < max_failed:
-            self._iterate(dev)
+            try:
+                self._iterate(dev)
+            except RuntimeError:
+                break
             elapsed = round(time() - start, 1)
-        pomace.log.info(f"Stopping {self.name} after {elapsed} seconds")
+        pomace.log.info(f"Stopping {self.title} after {elapsed} seconds")
 
     def _iterate(self, dev: bool):
         self.attempted += 1
-        pomace.log.info(f"Starting {self.name} iteration {self.attempted}")
+        pomace.log.info(f"Starting {self.title} iteration {self.attempted}")
 
         page = self.init()
-
         page = self.run(page)
 
         if self.check(page):
